"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const cli_ux_1 = require("cli-ux");
const path = require("path");
const misc_1 = require("../misc");
class Package extends command_1.Command {
    async run() {
        const { flags } = this.parse(Package);
        cli_ux_1.default.action.start('packaging your app');
        const fd = new misc_1.FolderDetails(this);
        try {
            await fd.readInfoFile();
        }
        catch (e) {
            this.error(e.message);
            return;
        }
        const compiler = new misc_1.AppCompiler(this, fd);
        const report = compiler.logDiagnostics();
        if (!report.isValid && !flags.force) {
            this.error('TypeScript compiler error(s) occurred');
            this.exit(1);
            return;
        }
        const packager = new misc_1.AppPackager(this, fd);
        const zipName = await packager.zipItUp();
        cli_ux_1.default.action.stop('finished!');
        this.log(chalk_1.default.black(' '));
        this.log(chalk_1.default.green('App packaged up at:'), path.join(fd.folder, zipName));
    }
}
Package.description = 'packages up your App in a distributable format';
Package.aliases = ['p', 'pack'];
Package.flags = {
    help: command_1.flags.help({ char: 'h' }),
    // flag with no value (-f, --force)
    force: command_1.flags.boolean({
        char: 'f',
        description: 'forcefully package the App, ignores lint & TypeScript errors',
    }),
};
exports.default = Package;
//# sourceMappingURL=package.js.map