"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const ts = require("typescript");
const compilerOptions_1 = require("./compilerOptions");
const diagnosticReport_1 = require("./diagnosticReport");
class AppCompiler {
    constructor(command, fd) {
        this.command = command;
        this.fd = fd;
        this.program = ts.createProgram({
            rootNames: [this.fd.mainFile],
            options: compilerOptions_1.compilerOptions,
        });
    }
    // TODO: Determine which diagnostics we need to actually report, or is preEmit fine?
    logDiagnostics() {
        const report = new diagnosticReport_1.DiagnosticReport();
        report.options = this.reportDiagnostics(this.program.getOptionsDiagnostics());
        report.syntactic = this.reportDiagnostics(this.program.getSyntacticDiagnostics());
        report.global = this.reportDiagnostics(this.program.getGlobalDiagnostics());
        // report.semantic = this.reportDiagnostics(this.program.getSemanticDiagnostics());
        report.declaration = this.reportDiagnostics(this.program.getDeclarationDiagnostics());
        report.emit = this.reportDiagnostics(ts.getPreEmitDiagnostics(this.program));
        return report;
    }
    reportDiagnostics(diagnos) {
        for (const d of diagnos) {
            if (!d.file || !d.start) {
                this.command.warn(ts.DiagnosticCategory[d.category].toLowerCase() +
                    d.code + ': ' + ts.flattenDiagnosticMessageText(d.messageText, '\n'));
                continue;
            }
            const startPos = ts.getLineAndCharacterOfPosition(d.file, d.start);
            // tslint:disable-next-line:max-line-length
            const redPart = chalk_1.default.red(`${d.file.fileName} (${startPos.line + 1},${startPos.character + 1}): \n  `);
            this.command.error(redPart + ts.flattenDiagnosticMessageText(d.messageText, '\n'), { exit: false });
        }
        return diagnos.length;
    }
}
exports.AppCompiler = AppCompiler;
//# sourceMappingURL=appCompiler.js.map