"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const glob = require("glob");
const path = require("path");
const Yazl = require("yazl");
class AppPackager {
    constructor(command, fd) {
        this.command = command;
        this.fd = fd;
    }
    async zipItUp() {
        let matches;
        try {
            matches = await this.asyncGlob();
        }
        catch (e) {
            this.command.warn(`Failed to retrieve the list of files for the App ${this.fd.info.name}.`);
            throw e;
        }
        // Ensure we have some files to package up before we do the packaging
        if (matches.length === 0) {
            throw new Error('No files to package were found');
        }
        const zipName = `dist${path.sep}${this.fd.info.nameSlug}_${this.fd.info.version}.zip`;
        const zip = new Yazl.ZipFile();
        zip.addBuffer(Buffer.from(JSON.stringify(AppPackager.PackagerInfo)), '.packagedby', { compress: true });
        for (const realPath of matches) {
            const zipPath = realPath.replace(this.fd.folder + path.sep, '');
            const fileStat = await fs.stat(realPath);
            const options = {
                compress: true,
                mtime: fileStat.mtime,
                mode: fileStat.mode,
            };
            zip.addFile(realPath, zipPath, options);
        }
        zip.end();
        await this.asyncWriteZip(zip, zipName);
        return zipName;
    }
    // tslint:disable-next-line:promise-function-async
    asyncGlob() {
        return new Promise((resolve, reject) => {
            glob(this.fd.toZip, AppPackager.GlobOptions, (err, matches) => {
                if (err) {
                    reject(err);
                    return;
                }
                resolve(matches);
            });
        });
    }
    // tslint:disable-next-line:promise-function-async
    asyncWriteZip(zip, zipName) {
        return new Promise((resolve) => {
            fs.mkdirpSync(this.fd.mergeWithFolder('dist'));
            const realPath = this.fd.mergeWithFolder(zipName);
            zip.outputStream.pipe(fs.createWriteStream(realPath)).on('close', resolve);
        });
    }
}
AppPackager.GlobOptions = {
    dot: false,
    silent: true,
    ignore: [
        '**/README.md',
        '**/package-lock.json',
        '**/package.json',
        '**/tslint.json',
        '**/tsconfig.json',
        '**/*.js',
        '**/*.js.map',
        '**/*.d.ts',
        '**/dist/**',
        '**/.*',
    ],
};
AppPackager.PackagerInfo = {
    tool: '@rocket.chat/apps-cli',
    version: '1.4.0',
};
exports.AppPackager = AppPackager;
//# sourceMappingURL=appPackager.js.map